@@ -3,7 +3,7 @@ import transaction
 
 from datetime import datetime
 from onegov.event import Event, Occurrence
-from sedate import replace_timezone, to_timezone
+from sedate import replace_timezone
 
 
 def tzdatetime(year, month, day, hour, minute, timezone):
@@ -122,14 +122,14 @@ def test_occurrence_dates(session):
     dates = event.occurrence_dates()
     assert len(dates) == 2
     assert dates[0] == tzdatetime(year, 2, 7, 10, 15, 'Europe/Zurich')
-    assert dates[1] == tzdatetime(year+1, 2, 7, 10, 15, 'Europe/Zurich')
+    assert dates[1] == tzdatetime(year + 1, 2, 7, 10, 15, 'Europe/Zurich')
     assert str(dates[0].tzinfo) == 'UTC'
     assert str(dates[1].tzinfo) == 'UTC'
 
     dates = event.occurrence_dates(localize=True)
     assert len(dates) == 2
     assert dates[0] == tzdatetime(year, 2, 7, 10, 15, 'Europe/Zurich')
-    assert dates[1] == tzdatetime(year+1, 2, 7, 10, 15, 'Europe/Zurich')
+    assert dates[1] == tzdatetime(year + 1, 2, 7, 10, 15, 'Europe/Zurich')
     assert str(dates[0].tzinfo) == 'Europe/Zurich'
     assert str(dates[1].tzinfo) == 'Europe/Zurich'
 
@@ -143,14 +143,14 @@ def test_occurrence_dates(session):
     dates = event.occurrence_dates()
     assert len(dates) == 2
     assert dates[0] == tzdatetime(year, 2, 7, 10, 15, 'Europe/Zurich')
-    assert dates[1] == tzdatetime(year+1, 2, 7, 10, 15, 'Europe/Zurich')
+    assert dates[1] == tzdatetime(year + 1, 2, 7, 10, 15, 'Europe/Zurich')
     assert str(dates[0].tzinfo) == 'UTC'
     assert str(dates[1].tzinfo) == 'UTC'
 
     dates = event.occurrence_dates(localize=True)
     assert len(dates) == 2
     assert dates[0] == tzdatetime(year, 2, 7, 10, 15, 'Europe/Zurich')
-    assert dates[1] == tzdatetime(year+1, 2, 7, 10, 15, 'Europe/Zurich')
+    assert dates[1] == tzdatetime(year + 1, 2, 7, 10, 15, 'Europe/Zurich')
     assert str(dates[0].tzinfo) == 'Europe/Zurich'
     assert str(dates[1].tzinfo) == 'Europe/Zurich'
 
@@ -313,8 +313,8 @@ def test_create_event_recurring_limit(session):
     assert len(occurrences) == 2
     assert occurrences[0].start == tzdatetime(year, 2, 7, 10, 15, timezone)
     assert occurrences[0].end == tzdatetime(year, 2, 7, 16, 00, timezone)
-    assert occurrences[1].start == tzdatetime(year+1, 2, 7, 10, 15, timezone)
-    assert occurrences[1].end == tzdatetime(year+1, 2, 7, 16, 00, timezone)
+    assert occurrences[1].start == tzdatetime(year + 1, 2, 7, 10, 15, timezone)
+    assert occurrences[1].end == tzdatetime(year + 1, 2, 7, 16, 00, timezone)
 
 
 def test_update_event(session):
@@ -465,3 +465,60 @@ def test_delete_event(session):
     session.expire_all()
     assert session.query(Event).count() == 0
     assert session.query(Occurrence).count() == 0
+
+
+def test_as_ical():
+    url = 'https://example.org/my-event'
+    event = Event(
+        state='initiated',
+        timezone='Europe/Zurich',
+        start=tzdatetime(2008, 2, 7, 10, 15, 'Europe/Zurich'),
+        end=tzdatetime(2008, 2, 7, 16, 00, 'Europe/Zurich'),
+        recurrence='RRULE:FREQ=DAILY;INTERVAL=2;COUNT=5',
+        title='Squirrel Park Visit',
+        content={'description': '<em>Furry</em> things will happen!'},
+        location='Squirrel Park',
+        tags=['fun', 'animals', 'furry'],
+        meta={'submitter': 'fat.pauly@squirrelpark.org'},
+        name='event',
+        modified=tzdatetime(2008, 2, 7, 10, 15, 'Europe/Zurich'),
+    )
+    ical = event.as_ical(url=url).decode().strip().split('\r\n')
+    assert sorted(ical) == sorted([
+        'BEGIN:VCALENDAR',
+        'VERSION:2.0',
+        'PRODID:-//OneGov//onegov.event//',
+        'BEGIN:VEVENT',
+        'SUMMARY:Squirrel Park Visit',
+        'DTSTART;VALUE=DATE-TIME:20080207T091500Z',
+        'DTEND;VALUE=DATE-TIME:20080207T150000Z',
+        'DESCRIPTION:<em>Furry</em> things will happen!',
+        'LAST-MODIFIED;VALUE=DATE-TIME:20080207T091500Z',
+        'LOCATION:Squirrel Park',
+        'RRULE:FREQ=DAILY;COUNT=5;INTERVAL=2',
+        'URL:https://example.org/my-event',
+        'END:VEVENT',
+        'END:VCALENDAR',
+    ])
+
+    event.submit()
+    event.publish()
+    occurrence = event.occurrences[0]
+    occurrence.modified = tzdatetime(2008, 2, 7, 10, 15, 'Europe/Zurich')
+
+    ical = event.occurrences[0].as_ical(url=url).decode().strip().split('\r\n')
+    assert sorted(ical) == sorted([
+        'BEGIN:VCALENDAR',
+        'VERSION:2.0',
+        'PRODID:-//OneGov//onegov.event//',
+        'BEGIN:VEVENT',
+        'SUMMARY:Squirrel Park Visit',
+        'DTSTART;VALUE=DATE-TIME:20080207T091500Z',
+        'DTEND;VALUE=DATE-TIME:20080207T150000Z',
+        'DESCRIPTION:<em>Furry</em> things will happen!',
+        'LAST-MODIFIED;VALUE=DATE-TIME:20080207T091500Z',
+        'LOCATION:Squirrel Park',
+        'URL:https://example.org/my-event',
+        'END:VEVENT',
+        'END:VCALENDAR',
+    ])
